@@ -1,5 +1,5 @@
 ## File Name: frm_fb_partable.R
-## File Version: 0.19
+## File Version: 0.37
 
 frm_fb_partable <- function( ind0 , parms_mcmc )
 {
@@ -25,7 +25,6 @@ frm_fb_partable <- function( ind0 , parms_mcmc )
 			dfr1 <- data.frame( 
 						"index" =  parms_index[[mm]][1] ,	
 						"model" = mm , 
-						# "type" = model_mm , 
 						"dv" = dv_mm , "parm" = c1 ,
 						"ON" = 1 , "est" = NA )
 			c2 <- ind0[[mm]]$coef_MH
@@ -57,13 +56,17 @@ frm_fb_partable <- function( ind0 , parms_mcmc )
 		}		
 		dfr <- rbind( dfr1 , dfr )
 	}
+		
 	NP <- nrow(dfr)
 	dfr <- data.frame("index" = 1:NP , dfr )
 	rownames(dfr) <- NULL
 	dfr <- dfr[ ! is.na( dfr$idparm ) , ]
 	
+	#-- include labels bctreg or yjtreg
+	dfr <- frm_modify_parameter_labels( dfr=dfr, ind0=ind0, NM=NM )
+	#-- include labels thresholds
 	dfr <- frm_partable_thresholds(partable=dfr)
-	
+
 	#--- compute statistics
 	values <- parms_mcmc$values	
 	est <- colMeans( values )
@@ -73,7 +76,7 @@ frm_fb_partable <- function( ind0 , parms_mcmc )
 	
 	p1 <- colMeans( values > 0 )
 	p2 <- colMeans( values < 0 )
-	y0 <- ifelse( p1 < p2 , p1 , p2 )
+	y0 <- 2 * ifelse( p1 < p2 , p1 , p2 )
 	dfr[ , "p" ] <- y0[ind1]
 	dfr[ , "lower95"] <- apply( values, 2 , stats::quantile , probs = .025 )[ind1]
 	dfr[ , "upper95"] <- apply( values, 2 , stats::quantile , probs = .975 )[ind1]
@@ -81,6 +84,10 @@ frm_fb_partable <- function( ind0 , parms_mcmc )
 	#--- convert parameter values into coda object
 	NV <- ncol(values)
 	values <- values[ , seq(NV,1,-1) ]
+	dfr11 <- dfr[ order(dfr$idparm) , ]
+	dfr11 <- dfr11[ seq(NV,1,-1) , ]
+	colnames(values) <- paste(dfr$parm)
+
 	values_coda <- coda::mcmc(data= values, start = min(parms_mcmc$iter_save), 
 								end = max(parms_mcmc$iter_save) , 
 								thin = diff(parms_mcmc$iter_save)[1] )
@@ -89,19 +96,27 @@ frm_fb_partable <- function( ind0 , parms_mcmc )
 	#--- technical summary MCMC algorithm
 	dfr2 <- dfr[ , 1:5]
 	dfr2[,"Nsampled"] <- nrow(values)
-	dfr2[,"effsize"] <- coda::effectiveSize(values_coda)[ind1]
-	dfr2[,"accrate"] <- accrate[ind1]
+	
+	colnames(values_coda) <- gsub( "ON difflogthresh", "difflogthresh", colnames(values_coda))
+	es <- coda::effectiveSize(values_coda)
+	
+	parnames <- paste(dfr2$parm)	
+	dfr2[,"effsize"] <- es[parnames]
+	dfr2[,"accrate"] <- accrate
+
 	#* compute Rhat function
-	dfr2[,"Rhat"] <- sirt::mcmc_Rhat( mcmc_object = values_coda , n_splits = 3 )[ind1]
-		
+	r1 <- sirt::mcmc_Rhat( mcmc_object = values_coda , n_splits = 3 )
+	dfr2[,"Rhat"] <- r1[ parnames ]
+	
 	#--- covariance matrix of parameters
 	coefs <- dfr$est
-	names(coefs) <- dfr$parm
-	vcovs <- stats::cov( values[, ind1]  )
+	names(coefs) <- dfr$parm	
+	colnames(values) <- gsub( "ON difflogthresh", "difflogthresh", colnames(values))
 	
+	vcovs <- stats::cov( values[, parnames]  )
 	dfr$index <- NULL
 	dfr2$index <- NULL
-	
+
 	#--- output
 	res <- list( partable = dfr, tech_summary = dfr2 , vcov = vcovs,
 					coef = coefs , values_coda = values_coda )
